Various sinks for generating image dataset statistics:

* `label-dist-[ic|is|od]`: label distribution output
* `to-annotation-overlay-od`: generates an image with all the annotation shapes (bbox or polygon) overlayed
